<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs_CS">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About </source>
        <translation>O aplikaci </translation>
    </message>
    <message>
        <source>About</source>
        <translation>O aplikaci</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Verze</translation>
    </message>
    <message>
        <source>Author</source>
        <translation>Autor</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zavřít</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Podpořit vývoj darem</translation>
    </message>
    <message>
        <source>Contact</source>
        <translation>Kontakt</translation>
    </message>
</context>
<context>
    <name>AboutTab</name>
    <message>
        <source>License: </source>
        <translation>Licence: </translation>
    </message>
    <message>
        <source>Screenshot and Annotation Tool</source>
        <translation>Aplikace pro zachycení snímku obrazovky a tvorbu popisků</translation>
    </message>
</context>
<context>
    <name>ActionSettingTab</name>
    <message>
        <source>Name</source>
        <translation>Název</translation>
    </message>
    <message>
        <source>Shortcut</source>
        <translation>Zkratka</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Vymazat</translation>
    </message>
    <message>
        <source>Take Capture</source>
        <translation>Zachytit</translation>
    </message>
    <message>
        <source>Include Cursor</source>
        <translation>Včetně kurzoru</translation>
    </message>
    <message>
        <source>Delay</source>
        <translation>Zpoždění</translation>
    </message>
    <message>
        <source>s</source>
        <extracomment>The small letter s stands for seconds.</extracomment>
        <translation>s</translation>
    </message>
    <message>
        <source>Capture Mode</source>
        <translation>Režim Zachycení</translation>
    </message>
    <message>
        <source>Show image in Pin Window</source>
        <translation>Zobraz obrázek v samostatném okně</translation>
    </message>
    <message>
        <source>Copy image to Clipboard</source>
        <translation>Zkopírovat obrázek do schránky</translation>
    </message>
    <message>
        <source>Upload image</source>
        <translation>Nahrát obrázek</translation>
    </message>
    <message>
        <source>Open image parent directory</source>
        <translation>Otevřít nadřazený adresář obrázku</translation>
    </message>
    <message>
        <source>Save image</source>
        <translation>Uložit obrázek</translation>
    </message>
    <message>
        <source>Hide Main Window</source>
        <translation>Skryj hlavní okno</translation>
    </message>
</context>
<context>
    <name>ActionsSettings</name>
    <message>
        <source>Add</source>
        <translation>Přidat</translation>
    </message>
    <message>
        <source>Actions Settings</source>
        <translation>Nastavení akcí</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Akce</translation>
    </message>
</context>
<context>
    <name>AddWatermarkOperation</name>
    <message>
        <source>Watermark Image Required</source>
        <translation>Je vyžadován obrázek vodoznaku</translation>
    </message>
    <message>
        <source>Please add a Watermark Image via Options &gt; Settings &gt; Annotator &gt; Update</source>
        <translation>Přidejte obrázek vodoznaku přes Možnosti&gt; Nastavení&gt; Značkovač&gt; Aktualizovat</translation>
    </message>
</context>
<context>
    <name>AnnotationSettings</name>
    <message>
        <source>Smooth Painter Paths</source>
        <translation>Vyhlazovat cesty kreslení</translation>
    </message>
    <message>
        <source>When enabled smooths out pen and
marker paths after finished drawing.</source>
        <translation>Pokud je povoleno, vyhlazuje čáry pera a
cesty zvýrazňovačů po dokončení kreslení.</translation>
    </message>
    <message>
        <source>Smooth Factor</source>
        <translation>Síla vyhlazení</translation>
    </message>
    <message>
        <source>Increasing the smooth factor will decrease
precision for pen and marker but will
make them more smooth.</source>
        <translation>Zvýšením síly vyhlazení se sníží
přesnost pera a značkovače, ale bude
je více vyhlazovat.</translation>
    </message>
    <message>
        <source>Annotator Settings</source>
        <translation>Nastavení značkovače</translation>
    </message>
    <message>
        <source>Remember annotation tool selection and load on startup</source>
        <translation>Zapamatovat výběr anotačního nástroje a nahrát jej při startu</translation>
    </message>
    <message>
        <source>Switch to Select Tool after drawing Item</source>
        <translation>Přepnout do Nástroje pro výběr po nakreslení položky</translation>
    </message>
    <message>
        <source>Number Tool Seed change updates all Number Items</source>
        <translation>Změna nástroje pro číslování aktualizuje všechny číselné položky</translation>
    </message>
    <message>
        <source>Disabling this option causes changes of the number tool
seed to affect only new items but not existing items.
Disabling this option allows having duplicate numbers.</source>
        <translation>Zakázání této možnosti způsobí, že změny nástroje pro číslování
 ovlivní pouze nové položky, ne však ty existující.
 Zakázání této možniosti povolí duplicitní číslování.</translation>
    </message>
    <message>
        <source>Canvas Color</source>
        <translation>Barva plátna</translation>
    </message>
    <message>
        <source>Default Canvas background color for annotation area.
Changing color affects only new annotation areas.</source>
        <translation>Výchozí barva pozadí plátna pro oblast poznámek.
Změna barvy ovlivní pouze nové oblasti anotací.</translation>
    </message>
    <message>
        <source>Select Item after drawing</source>
        <translation>Po kreslení vyber prvek</translation>
    </message>
    <message>
        <source>With this option enabled the item gets selected after
being created, allowing changing settings.</source>
        <translation>S výběrem této volby získá prvek okamžité vybrání poté,
co je vytvořen. A zpřístupní možnost editace prvku.</translation>
    </message>
</context>
<context>
    <name>ApplicationSettings</name>
    <message>
        <source>Capture screenshot at startup with default mode</source>
        <translation>Zachytit snímek obrazovky při spuštění ve výchozím režimu</translation>
    </message>
    <message>
        <source>Application Style</source>
        <translation>Styl aplikace</translation>
    </message>
    <message>
        <source>Sets the application style which defines the look and feel of the GUI.
Change requires ksnip restart to take effect.</source>
        <translation>Nastavuje styl aplikace, který definuje vzhled GUI.
Změna vyžaduje restartování aplikace.</translation>
    </message>
    <message>
        <source>Application Settings</source>
        <translation>Nastavení aplikace</translation>
    </message>
    <message>
        <source>Automatically copy new captures to clipboard</source>
        <translation>Automaticky kopírovat nové snímky do schránky</translation>
    </message>
    <message>
        <source>Use Tabs</source>
        <translation>Použít karty</translation>
    </message>
    <message>
        <source>Change requires restart.</source>
        <translation>Změna vyžaduje restart.</translation>
    </message>
    <message>
        <source>Run ksnip as single instance</source>
        <translation>Spustit ksnip v jedné instanci</translation>
    </message>
    <message>
        <source>Hide Tabbar when only one Tab is used.</source>
        <translation>Skrýt panel karet, pokud je použita pouze jedna karta.</translation>
    </message>
    <message>
        <source>Enabling this option will allow only one ksnip instance to run,
all other instances started after the first will pass its
arguments to the first and close. Changing this option requires
a new start of all instances.</source>
        <translation>Povolení této možnosti umožní spuštění pouze jedné instance ksnip,
všechny ostatní instance spuštěné poté předají svoje argumenty první instanci.
 Změna této možnosti vyžaduje
restart všech instancí.</translation>
    </message>
    <message>
        <source>Remember Main Window position on move and load on startup</source>
        <translation>Zapamatovat pozici hlavního okna a načíst ji při startu aplikace</translation>
    </message>
    <message>
        <source>Auto hide Tabs</source>
        <translation>Automaticky skrývat karty</translation>
    </message>
    <message>
        <source>Auto hide Docks</source>
        <translation>Automaticky skrýt doky</translation>
    </message>
    <message>
        <source>On startup hide Toolbar and Annotation Settings.
Docks visibility can be toggled with the Tab Key.</source>
        <translation>Při spuštění skrýt panel nástrojů a Nastavení poznámek.
Viditelnost doků lze přepínat pomocí klávesy Tabulátor.</translation>
    </message>
    <message>
        <source>Auto resize to content</source>
        <translation>Automaticky změnit velikost podle obsahu</translation>
    </message>
    <message>
        <source>Automatically resize Main Window to fit content image.</source>
        <translation>Automaticky změnit velikost hlavního okna podle velikosti obrázku.</translation>
    </message>
    <message>
        <source>Enable Debugging</source>
        <translation>Povolit ladění aplikace</translation>
    </message>
    <message>
        <source>Enables debug output written to the console.
Change requires ksnip restart to take effect.</source>
        <translation>Povolit režim ladění do okna konzole.
Pro změnu je nutné restartovat ksnip.</translation>
    </message>
    <message>
        <source>Resize to content delay</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Resizing to content is delay to allow the Window Manager to receive
the new content. In case that the Main Windows is not adjusted correctly
to the new content, increasing this delay might improve the behavior.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AuthorTab</name>
    <message>
        <source>Contributors:</source>
        <translation>Přispěvatelé:</translation>
    </message>
    <message>
        <source>Spanish Translation</source>
        <translation>Španělský překlad</translation>
    </message>
    <message>
        <source>Dutch Translation</source>
        <translation>Holandský překlad</translation>
    </message>
    <message>
        <source>Russian Translation</source>
        <translation>Ruský překlad</translation>
    </message>
    <message>
        <source>Norwegian Bokmål Translation</source>
        <translation>Překlad do norštiny v bokmålu</translation>
    </message>
    <message>
        <source>French Translation</source>
        <translation>Francouzský překlad</translation>
    </message>
    <message>
        <source>Polish Translation</source>
        <translation>Polský překlad</translation>
    </message>
    <message>
        <source>Snap &amp; Flatpak Support</source>
        <translation>Podpora distribuce pomocí Snap &amp; Flatpak</translation>
    </message>
    <message>
        <source>The Authors:</source>
        <translation>Autoři:</translation>
    </message>
</context>
<context>
    <name>CanDiscardOperation</name>
    <message>
        <source>Warning - </source>
        <translation>Varování - </translation>
    </message>
    <message>
        <source>The capture %1%2%3 has been modified.
Do you want to save it?</source>
        <translation>Zachycení %1 %2 %3 bylo upraveno.
Chcete změny uložit?</translation>
    </message>
</context>
<context>
    <name>CaptureModePicker</name>
    <message>
        <source>New</source>
        <translation>Nový</translation>
    </message>
    <message>
        <source>Draw a rectangular area with your mouse</source>
        <translation>Nakreslete obdélníkovou oblast pomocí myši</translation>
    </message>
    <message>
        <source>Capture a screenshot of the last selected rectangular area</source>
        <translation>Zachytit snímek obrazovky poslední vybrané obdélníkové plochy</translation>
    </message>
    <message>
        <source>Capture full screen including all monitors</source>
        <translation>Zachytit celou obrazovku včetně všech monitorů</translation>
    </message>
    <message>
        <source>Capture screen where the mouse is located</source>
        <translation>Zachyťte obrazovku, kde se nachází myš</translation>
    </message>
    <message>
        <source>Capture window that currently has focus</source>
        <translation>Zachytit okno, které je v tuto chvíli zaměřeno</translation>
    </message>
    <message>
        <source>Capture that is currently under the mouse cursor</source>
        <translation>Zachycení okna, které je aktuálně pod kurzorem myši</translation>
    </message>
    <message>
        <source>Uses the screenshot Portal for taking screenshot</source>
        <translation>Používá Portál snímků obrazovky pro pořizování snímků obrazovky</translation>
    </message>
</context>
<context>
    <name>ContactTab</name>
    <message>
        <source>Community</source>
        <translation>Komunita</translation>
    </message>
    <message>
        <source>Bug Reports</source>
        <translation>Nahlášení chyb</translation>
    </message>
    <message>
        <source>If you have general questions, ideas or just want to talk about ksnip,&lt;br/&gt;please join our %1 or our %2 server.</source>
        <translation>Pokud máte obecné otázky, nápady nebo si jen chcete povídat o ksnip,&lt;br/&gt;prosím, připojte se na náš %1 nebo náš %2 server.</translation>
    </message>
    <message>
        <source>Please use %1 to report bugs.</source>
        <translation>Prosím použijte %1 pro nahlašování chyb.</translation>
    </message>
</context>
<context>
    <name>CopyAsDataUriOperation</name>
    <message>
        <source>Failed to copy to clipboard</source>
        <translation>Kopírování do schránky se nezdařilo</translation>
    </message>
    <message>
        <source>Failed to copy to clipboard as base64 encoded image.</source>
        <translation>Nezdařilo se kopírování base64 kodováného obrázku do schránky.</translation>
    </message>
    <message>
        <source>Copied to clipboard</source>
        <translation>zkopírovat do schránky</translation>
    </message>
    <message>
        <source>Copied to clipboard as base64 encoded image.</source>
        <translation>Zkopírováno do schránky jako base64 kódovaný obrázek.</translation>
    </message>
</context>
<context>
    <name>DeleteImageOperation</name>
    <message>
        <source>Delete Image</source>
        <translation>Smazat obrázek</translation>
    </message>
    <message>
        <source>The item &apos;%1&apos; will be deleted.
Do you want to continue?</source>
        <translation>Položka %1 bude odstraněna.
Chcete pokračovat?</translation>
    </message>
</context>
<context>
    <name>DonateTab</name>
    <message>
        <source>Donations are always welcome</source>
        <translation>Dary jsou vždy vítány</translation>
    </message>
    <message>
        <source>Donation</source>
        <translation>Sponzorský dar</translation>
    </message>
    <message>
        <source>ksnip is a non-profitable copyleft libre software project, and&lt;br/&gt;still has some costs that need to be covered,&lt;br/&gt;like domain costs or hardware costs for cross-platform support.</source>
        <translation>ksnip je neziskový copyleft volný softwarový projekt a &lt;br/&gt; stále má nějaké výdaje, které je třeba pokrýt,&lt;br/&gt;jako domény nebo hardware pro podporu více platforem.</translation>
    </message>
    <message>
        <source>If you want to help or just want to appreciate the work being done&lt;br/&gt;by treating developers to a beer or coffee, you can do that %1here%2.</source>
        <translation>Pokud chcete pomoct nebo jen chcete ocenit práci, kterou děláme,&lt;br/&gt;tím, že zaplatíte vývojářům pivo nebo kávu, můžete tak učinit %1zde%2.</translation>
    </message>
    <message>
        <source>Become a GitHub Sponsor?</source>
        <translation>Stát se GitHub sponzorem?</translation>
    </message>
    <message>
        <source>Also possible, %1here%2.</source>
        <translation>Také možnost, %1zde%2.</translation>
    </message>
</context>
<context>
    <name>EmptyActionSettingTab</name>
    <message>
        <source>Add new actions by pressing the &apos;Add&apos; tab button.</source>
        <translation>Nové akce přidáte stisknutím tlačítka na kartě &quot;Přidat&quot;.</translation>
    </message>
</context>
<context>
    <name>EnumTranslator</name>
    <message>
        <source>Rectangular Area</source>
        <translation>Obdélníková oblast</translation>
    </message>
    <message>
        <source>Last Rectangular Area</source>
        <translation>Poslední obdélníková oblast</translation>
    </message>
    <message>
        <source>Full Screen (All Monitors)</source>
        <translation>Celá obrazovka (všechny monitory)</translation>
    </message>
    <message>
        <source>Current Screen</source>
        <translation>Aktuální obrazovka</translation>
    </message>
    <message>
        <source>Active Window</source>
        <translation>Aktivní okno</translation>
    </message>
    <message>
        <source>Window Under Cursor</source>
        <translation>Okno pod kurzorem</translation>
    </message>
    <message>
        <source>Screenshot Portal</source>
        <translation>Portál snímků obrazovky</translation>
    </message>
</context>
<context>
    <name>FtpUploaderSettings</name>
    <message>
        <source>Force anonymous upload.</source>
        <translation>Vynutit anonymní nahrání.</translation>
    </message>
    <message>
        <source>Url</source>
        <translation>Url</translation>
    </message>
    <message>
        <source>Username</source>
        <translation type="unfinished">Uživatelské jméno</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Heslo</translation>
    </message>
    <message>
        <source>FTP Uploader</source>
        <translation>Nahrání na FTP</translation>
    </message>
</context>
<context>
    <name>HandleUploadResultOperation</name>
    <message>
        <source>Upload Successful</source>
        <translation>Odeslání proběhlo úspěšně</translation>
    </message>
    <message>
        <source>Unable to save temporary image for upload.</source>
        <translation>Nelze uložit dočasný obrázek pro nahrání.</translation>
    </message>
    <message>
        <source>Unable to start process, check path and permissions.</source>
        <translation>Nelze spustit proces, zkontrolujte cestu a oprávnění.</translation>
    </message>
    <message>
        <source>Process crashed</source>
        <translation>Proces selhal</translation>
    </message>
    <message>
        <source>Process timed out.</source>
        <translation>Proces vypršel.</translation>
    </message>
    <message>
        <source>Process read error.</source>
        <translation>Chyba čtení procesu.</translation>
    </message>
    <message>
        <source>Process write error.</source>
        <translation>Chyba zápisu procesu.</translation>
    </message>
    <message>
        <source>Web error, check console output.</source>
        <translation>Chyba webu, zkontrolujte výstup konzoly.</translation>
    </message>
    <message>
        <source>Upload Failed</source>
        <translation>Nahrání se nezdařilo</translation>
    </message>
    <message>
        <source>Script wrote to StdErr.</source>
        <translation>Skript zapisoval do StdErr.</translation>
    </message>
    <message>
        <source>FTP Upload finished successfully.</source>
        <translation>Byl úspěšně dokončen FTP přenos.</translation>
    </message>
    <message>
        <source>Unknown error.</source>
        <translation>Neznámá chyba.</translation>
    </message>
    <message>
        <source>Connection Error.</source>
        <translation>Chyba připojení.</translation>
    </message>
    <message>
        <source>Permission Error.</source>
        <translation>Chyba v přístupových oprávnění.</translation>
    </message>
    <message>
        <source>Upload script %1  finished successfully.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Uploaded to %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HotKeySettings</name>
    <message>
        <source>Enable Global HotKeys</source>
        <translation>Povolit globální klávesové zkratky</translation>
    </message>
    <message>
        <source>Capture Rect Area</source>
        <translation>Zachytit oblast obdélníku</translation>
    </message>
    <message>
        <source>Capture Last Rect Area</source>
        <translation>Zachytit poslední oblast obdélníku</translation>
    </message>
    <message>
        <source>Capture Full Screen</source>
        <translation>Zachytit celou obrazovku</translation>
    </message>
    <message>
        <source>Capture current Screen</source>
        <translation>Zachytit aktuální obrazovku</translation>
    </message>
    <message>
        <source>Capture active Window</source>
        <translation>Zachytit aktivní okno</translation>
    </message>
    <message>
        <source>Capture Window under Cursor</source>
        <translation>Zachytit okno pod kurzorem</translation>
    </message>
    <message>
        <source>Global HotKeys</source>
        <translation>Globální klávesové zkratky</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Vymazat</translation>
    </message>
    <message>
        <source>Capture using Portal</source>
        <translation>Zachycení pomocí portálu</translation>
    </message>
    <message>
        <source>HotKeys are currently supported only for Windows and X11.
Disabling this option makes also the action shortcuts ksnip only.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImageGrabberSettings</name>
    <message>
        <source>Capture mouse cursor on screenshot</source>
        <translation>Zachytit kurzor myši na snímku</translation>
    </message>
    <message>
        <source>Should mouse cursor be visible on
screenshots.</source>
        <translation>Kurzor myši bude viditelný 
na snímku obrazovky.</translation>
    </message>
    <message>
        <source>Image Grabber</source>
        <translation>Snímkování</translation>
    </message>
    <message>
        <source>Generic Wayland implementations that use
XDG-DESKTOP-PORTAL handle screen scaling
differently. Enabling this option will
determine the current screen scaling and
apply that to the screenshot in ksnip.</source>
        <translation>Generické implementace Wayland, které používají
XDG-DESKTOP-PORTAL ošetřují měřítko obrazovky
rozdílným způsobem. Povolení této možnosti bude
určeno aktuální měřítko obrazovky a
aplikováno na snímek obrazovky v ksnip.</translation>
    </message>
    <message>
        <source>GNOME and KDE Plasma support their own Wayland
and the Generic XDG-DESKTOP-PORTAL screenshots.
Enabling this option will force KDE Plasma and
GNOME to use the XDG-DESKTOP-PORTAL screenshots.
Change in this option require a ksnip restart.</source>
        <translation>GNOME and KDE Plasma podporují pro Wayland
a Generic XDG-DESKTOP-PORTAL jejich vlastní snímkování obrazovky.
Zapnutí této možnosti přinutí KDE Plasma a
GNOME použít XDG-DESKTOP-PORTAL snímkování obrazovky.
Změna tohoto nastavení se projeví po restartu ksnip.</translation>
    </message>
    <message>
        <source>Show Main Window after capturing screenshot</source>
        <translation>Zobrazit hlavní okno po pořízení snímku obrazovky</translation>
    </message>
    <message>
        <source>Hide Main Window during screenshot</source>
        <translation>Skrýt hlavní okno během snímku obrazovky</translation>
    </message>
    <message>
        <source>Hide Main Window when capturing a new screenshot.</source>
        <translation>Skrýt hlavní okno při pořizování nového snímku obrazovky.</translation>
    </message>
    <message>
        <source>Show Main Window after capturing a new screenshot
when the Main Window was hidden or minimize.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Force Generic Wayland (xdg-desktop-portal) Screenshot</source>
        <translation>Vynutit snímek přes Wayland Generic (xdg-desktop-portal)</translation>
    </message>
    <message>
        <source>Scale Generic Wayland (xdg-desktop-portal) Screenshots</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImgurHistoryDialog</name>
    <message>
        <source>Imgur History</source>
        <translation>Historie Imgur</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zavřít</translation>
    </message>
    <message>
        <source>Time Stamp</source>
        <translation>Časové razítko</translation>
    </message>
    <message>
        <source>Link</source>
        <translation>Odkaz</translation>
    </message>
    <message>
        <source>Delete Link</source>
        <translation>Odstranit odkaz</translation>
    </message>
</context>
<context>
    <name>ImgurUploader</name>
    <message>
        <source>Upload to imgur.com finished!</source>
        <translation>Nahrávání na imgur.com dokončeno!</translation>
    </message>
    <message>
        <source>Received new token, trying upload again…</source>
        <translation>Byl přijat nový token, zkouším znovu odeslat …</translation>
    </message>
    <message>
        <source>Imgur token has expired, requesting new token…</source>
        <translation>Platnost tokenu imgur vypršela, žádání o nový token…</translation>
    </message>
</context>
<context>
    <name>ImgurUploaderSettings</name>
    <message>
        <source>Force anonymous upload</source>
        <translation>Vynutit anonymní odesílání</translation>
    </message>
    <message>
        <source>After uploading open Imgur link in default browser</source>
        <translation>Po odeslání otevřít odkaz Imgur ve výchozím prohlížeči</translation>
    </message>
    <message>
        <source>Always copy Imgur link to clipboard</source>
        <translation>Vždy kopírovat odkaz Imgur do schránky</translation>
    </message>
    <message>
        <source>Client ID</source>
        <translation>ID klienta</translation>
    </message>
    <message>
        <source>Client Secret</source>
        <translation>Heslo klienta</translation>
    </message>
    <message>
        <source>PIN</source>
        <translation>PIN</translation>
    </message>
    <message>
        <source>Enter imgur Pin which will be exchanged for a token.</source>
        <translation>Zadejte PIN Imgur, který bude vyměněn za token.</translation>
    </message>
    <message>
        <source>Get PIN</source>
        <translation>Získat PIN</translation>
    </message>
    <message>
        <source>Get Token</source>
        <translation>Získat token</translation>
    </message>
    <message>
        <source>Imgur History</source>
        <translation>Historie Imgur</translation>
    </message>
    <message>
        <source>Imgur Uploader</source>
        <translation>Imgur služba</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Uživatelské jméno</translation>
    </message>
    <message>
        <source>Waiting for imgur.com…</source>
        <translation>Čekání na imgur.com…</translation>
    </message>
    <message>
        <source>Imgur.com token successfully updated.</source>
        <translation>Token Imgur.com byl úspěšně aktualizován.</translation>
    </message>
    <message>
        <source>Imgur.com token update error.</source>
        <translation>Chyba aktualizace Imgur.com tokenu.</translation>
    </message>
    <message>
        <source>Link directly to image</source>
        <translation>Odkaz přímo na obrázek</translation>
    </message>
    <message>
        <source>Base Url:</source>
        <translation>Základní adresa URL:</translation>
    </message>
    <message>
        <source>Base url that will be used for communication with Imgur.
Changing requires restart.</source>
        <translation>Základní adresa URL, která bude použita pro komunikaci s Imgurem.
Změna vyžaduje restart.</translation>
    </message>
    <message>
        <source>Clear Token</source>
        <translation>Vymazat token</translation>
    </message>
</context>
<context>
    <name>LoadImageFromFileOperation</name>
    <message>
        <source>Unable to open image</source>
        <translation>Obrázek nelze otevřít</translation>
    </message>
    <message>
        <source>Unable to open image from path %1</source>
        <translation>Nelze otevřít obrázek z místa %1</translation>
    </message>
</context>
<context>
    <name>MainToolBar</name>
    <message>
        <source>New</source>
        <translation>Nový</translation>
    </message>
    <message>
        <source>Delay in seconds between triggering
and capturing screenshot.</source>
        <translation>Prodleva v sekundách mezi spuštěním
a zachycením obrazovky.</translation>
    </message>
    <message>
        <source>s</source>
        <extracomment>The small letter s stands for seconds.</extracomment>
        <translation>s</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Uložit</translation>
    </message>
    <message>
        <source>Save Screen Capture to file system</source>
        <translation>Uložit výstřižek obrazovky do systému souborů</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopírovat</translation>
    </message>
    <message>
        <source>Copy Screen Capture to clipboard</source>
        <translation>Kopírovat výstřižek obrazovky do schránky</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Zpět</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Znovu</translation>
    </message>
    <message>
        <source>Crop</source>
        <translation>Oříznutí</translation>
    </message>
    <message>
        <source>Crop Screen Capture</source>
        <translation>Oříznout snímek obrazovky</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Nástroje</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Unable to show image</source>
        <translation>Obrázek nelze zobrazit</translation>
    </message>
    <message>
        <source>Unsaved</source>
        <translation>Neuloženo</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Odeslat</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Tisk</translation>
    </message>
    <message>
        <source>Opens printer dialog and provide option to print image</source>
        <translation>Otevře dialog tiskárny a poskytne možnost pro tisk obrázku</translation>
    </message>
    <message>
        <source>Print Preview</source>
        <translation>Náhled tisku</translation>
    </message>
    <message>
        <source>Opens Print Preview dialog where the image orientation can be changed</source>
        <translation>Otevře dialog náhledu, kde lze změnit orientaci obrázku</translation>
    </message>
    <message>
        <source>Scale</source>
        <translation>Změnit velikost</translation>
    </message>
    <message>
        <source>Add Watermark</source>
        <translation>Přidat vodoznak</translation>
    </message>
    <message>
        <source>Add Watermark to captured image. Multiple watermarks can be added.</source>
        <translation>Přidat vodoznak do zachyceného obrázku. Lze přidat i více vodoznaků.</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Ukončit</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Nastavení</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;O aplikaci</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Otevřít</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Soubor</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Upravit</translation>
    </message>
    <message>
        <source>&amp;Options</source>
        <translation>&amp;Možnosti</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Pomoc</translation>
    </message>
    <message>
        <source>Save As...</source>
        <translation>Uložit jako...</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Vložit</translation>
    </message>
    <message>
        <source>Paste Embedded</source>
        <translation>Vložit do aktvní karty</translation>
    </message>
    <message>
        <source>Pin</source>
        <translation>PIN</translation>
    </message>
    <message>
        <source>Pin screenshot to foreground in frameless window</source>
        <translation>Připnout snímek obrazovky k popředí v bezrámovém okně</translation>
    </message>
    <message>
        <source>No image provided but one was expected.</source>
        <translation>Nebyl poskytnut žádný obrázek, ale jeden se očekával.</translation>
    </message>
    <message>
        <source>Copy Path</source>
        <translation>Kopírovat cestu</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>Otevřít adresář</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Pohled</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Vymazat</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Přejmenovat</translation>
    </message>
    <message>
        <source>Open Images</source>
        <translation>Otevřít obrázky</translation>
    </message>
    <message>
        <source>Show Docks</source>
        <translation>Zobrazit doky</translation>
    </message>
    <message>
        <source>Hide Docks</source>
        <translation>Skrýt doky</translation>
    </message>
    <message>
        <source>Copy as data URI</source>
        <translation>Kopírovat jako data URI</translation>
    </message>
    <message>
        <source>Open &amp;Recent</source>
        <translation>Otevřít nedávné</translation>
    </message>
    <message>
        <source>Modify Canvas</source>
        <translation>Upravit plátno</translation>
    </message>
    <message>
        <source>Upload triggerCapture to external source</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy triggerCapture to system clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scale Image</source>
        <translation>Změnit Velikost</translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation>Otočit</translation>
    </message>
    <message>
        <source>Rotate Image</source>
        <translation>Otočit Obrázek</translation>
    </message>
    <message>
        <source>Actions</source>
        <translation type="unfinished">Akce</translation>
    </message>
    <message>
        <source>Image Files</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MultiCaptureHandler</name>
    <message>
        <source>Save</source>
        <translation>Uložit</translation>
    </message>
    <message>
        <source>Save As</source>
        <translation>Uložit jako</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>Otevřít adresář</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopírovat</translation>
    </message>
    <message>
        <source>Copy Path</source>
        <translation>Kopírovat cestu</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Přejmenovat</translation>
    </message>
</context>
<context>
    <name>NewCaptureNameProvider</name>
    <message>
        <source>Capture</source>
        <translation>Zachytit</translation>
    </message>
</context>
<context>
    <name>PinWindow</name>
    <message>
        <source>Close</source>
        <translation>Zavřít</translation>
    </message>
    <message>
        <source>Close Other</source>
        <translation>Zavřít ostatní</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>Zavřít vše</translation>
    </message>
</context>
<context>
    <name>PinWindowHandler</name>
    <message>
        <source>Pin Window %1</source>
        <translation>Připnout okno %1</translation>
    </message>
</context>
<context>
    <name>RenameOperation</name>
    <message>
        <source>Image Renamed</source>
        <translation>Obrázek byl přejmenován</translation>
    </message>
    <message>
        <source>Image Rename Failed</source>
        <translation>Přejmenování obrázku se nezdařilo</translation>
    </message>
    <message>
        <source>Rename image</source>
        <translation>Přejmenovat obrázek</translation>
    </message>
    <message>
        <source>New filename:</source>
        <translation>Nový název souboru:</translation>
    </message>
    <message>
        <source>Successfully renamed image to %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to rename image to %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SaveOperation</name>
    <message>
        <source>Save As</source>
        <translation>Uložit jako</translation>
    </message>
    <message>
        <source>All Files</source>
        <translation>Všechny soubory</translation>
    </message>
    <message>
        <source>Image Saved</source>
        <translation>Obrázek uložen</translation>
    </message>
    <message>
        <source>Saving Image Failed</source>
        <translation>Ukládání obrázku selhalo</translation>
    </message>
    <message>
        <source>Image Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to save image to %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SaverSettings</name>
    <message>
        <source>Automatically save new captures to default location</source>
        <translation>Automaticky ukládat nové snímky do výchozího umístění</translation>
    </message>
    <message>
        <source>Prompt to save before discarding unsaved changes</source>
        <translation>Zobrazit výzvu k uložení před zahozením neuložených změn</translation>
    </message>
    <message>
        <source>Remember last Save Directory</source>
        <translation>Zapamatovat si poslední adresář uložení</translation>
    </message>
    <message>
        <source>When enabled will overwrite the save directory stored in settings
with the latest save directory, for every save.</source>
        <translation>Je-li povoleno, je přepsán adresář pro ukládání v Nastavení
cestou posledního uloženého obrázku pro každé následující uložení.</translation>
    </message>
    <message>
        <source>Capture save location and filename</source>
        <translation>Umístění a název souboru pro uložení zachycení</translation>
    </message>
    <message>
        <source>Supported Formats are JPG, PNG and BMP. If no format provided, PNG will be used as default.
Filename can contain following wildcards:
- $Y, $M, $D for date, $h, $m, $s for time, or $T for time in hhmmss format.
- Multiple consecutive # for counter. #### will result in 0001, next capture would be 0002.</source>
        <translation>Podporované formáty jsou JPG, PNG a BMP. Pokud není k dispozici žádný formát, použije se jako výchozí PNG.
Název souboru může obsahovat následující zástupné znaky:
- $Y, $M, $D pro datum, $h, $m, $s pro čas nebo $T pro čas ve formátu hhmmss.
- Více po sobě jdoucích # pro počítadlo. #### generuje první položku 0001, další snímek bude 0002.</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Procházet</translation>
    </message>
    <message>
        <source>Saver Settings</source>
        <translation>Nastavení Ukládače</translation>
    </message>
    <message>
        <source>Capture save location</source>
        <translation>Umístění pro uložení zachycení</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Výchozí</translation>
    </message>
    <message>
        <source>Factor</source>
        <translation>Faktor</translation>
    </message>
    <message>
        <source>Save Quality</source>
        <translation>Kvalita uložení</translation>
    </message>
    <message>
        <source>Specify 0 to obtain small compressed files, 100 for large uncompressed files.
Not all image formats support the full range, JPEG does.</source>
        <translation>Zadejte 0 pro získání malých komprimovaných souborů, 100 pro velké nekomprimované soubory.
Ne všechny formáty obrázků podporují celý rozsah, JPEG ano.</translation>
    </message>
</context>
<context>
    <name>ScriptUploaderSettings</name>
    <message>
        <source>Copy script output to clipboard</source>
        <translation>Kopírování výstupu skriptu do schránky</translation>
    </message>
    <message>
        <source>Script:</source>
        <translation>Skript:</translation>
    </message>
    <message>
        <source>Path to script that will be called for uploading. During upload the script will be called
with the path to a temporary png file as a single argument.</source>
        <translation>Cesta ke skriptu, který bude použit pro nahrávání. Během nahrávání bude skript volán
s jedním argumentem a to cestou k dočasnému souboru png.</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Procházet</translation>
    </message>
    <message>
        <source>Script Uploader</source>
        <translation>Nahrávací skript</translation>
    </message>
    <message>
        <source>Select Upload Script</source>
        <translation>Vybrat nahrávací skript</translation>
    </message>
    <message>
        <source>Stop when upload script writes to StdErr</source>
        <translation>Zastavit, když nahrávací skript zapíše do StdErr</translation>
    </message>
    <message>
        <source>Marks the upload as failed when script writes to StdErr.
Without this setting errors in the script will be unnoticed.</source>
        <translation>Označí nahrávání jako neúspěšné, když skript zapíše do StdErr.
Bez tohoto nastavení budou chyby ve skriptu ignorovány.</translation>
    </message>
    <message>
        <source>Filter:</source>
        <translation>Filter:</translation>
    </message>
    <message>
        <source>RegEx Expression. Only copy to clipboard what matches the RegEx Expression.
When omitted, everything is copied.</source>
        <translation>RegEx výraz. Zkopírujte do schránky pouze to, co odpovídá výrazu RegEx.
Když je vynechán, zkopíruje se vše.</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Settings</source>
        <translation>Nastavení</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <source>Application</source>
        <translation>Aplikace</translation>
    </message>
    <message>
        <source>Image Grabber</source>
        <translation>Snímkování</translation>
    </message>
    <message>
        <source>Imgur Uploader</source>
        <translation>Imgur služba</translation>
    </message>
    <message>
        <source>Annotator</source>
        <translation>Značkovač</translation>
    </message>
    <message>
        <source>HotKeys</source>
        <translation>Klávesové zkratky</translation>
    </message>
    <message>
        <source>Uploader</source>
        <translation>Nahrání</translation>
    </message>
    <message>
        <source>Script Uploader</source>
        <translation>Nahrávací skript</translation>
    </message>
    <message>
        <source>Saver</source>
        <translation>Ukládač</translation>
    </message>
    <message>
        <source>Stickers</source>
        <translation>Samolepky</translation>
    </message>
    <message>
        <source>Snipping Area</source>
        <translation>Výstřižková oblast</translation>
    </message>
    <message>
        <source>Tray Icon</source>
        <translation>Ikona v systémové oblasti</translation>
    </message>
    <message>
        <source>Watermark</source>
        <translation>Vodoznak</translation>
    </message>
    <message>
        <source>Actions</source>
        <translation>Akce</translation>
    </message>
    <message>
        <source>FTP Uploader</source>
        <translation type="unfinished">Nahrání na FTP</translation>
    </message>
</context>
<context>
    <name>SnippingAreaResizerInfoText</name>
    <message>
        <source>Resize selected rect using the handles or move it by dragging the selection.</source>
        <translation>Změňte velikost vybraného tvaru pomocí úchytů nebo jej přesuňte přetažením výběru.</translation>
    </message>
    <message>
        <source>Use arrow keys to move the selection.</source>
        <translation>K přesunutí výběru použijte klávesy se šipkami.</translation>
    </message>
    <message>
        <source>Use arrow keys while pressing CTRL to move top left handle.</source>
        <translation>Pomocí kláves se šipkami současně se stisknutou klávesou CTRL pohybujte levým horním úchytem.</translation>
    </message>
    <message>
        <source>Use arrow keys while pressing ALT to move bottom right handle.</source>
        <translation>Pomocí kláves se šipkami současně se stisknutou klávesou ALT posuňte pravý dolní úchyt.</translation>
    </message>
    <message>
        <source>Confirm selection by pressing ENTER/RETURN or abort by pressing ESC.</source>
        <translation>Potvrďte výběr stisknutím ENTER / RETURN nebo zrušte stisknutím ESC.</translation>
    </message>
    <message>
        <source>This message can be disabled via settings.</source>
        <translation>Tuto zprávu lze deaktivovat pomocí nastavení.</translation>
    </message>
</context>
<context>
    <name>SnippingAreaSelectorInfoText</name>
    <message>
        <source>Click and Drag to select a rectangular area or press ESC to quit.</source>
        <translation>Kliknutím a tažením vyberte obdélníkovou oblast nebo ji ukončete stisknutím klávesy ESC.</translation>
    </message>
    <message>
        <source>Hold CTRL pressed to resize selection after selecting.</source>
        <translation>Po výběru podržte stisknutou klávesu CTRL a změňte tak velikost výběru.</translation>
    </message>
    <message>
        <source>Hold CTRL pressed to prevent resizing after selecting.</source>
        <translation>Podržte stisknutou klávesu CTRL, abyste po výběru zabránili změně velikosti.</translation>
    </message>
    <message>
        <source>Operation will be canceled after 60 sec when no selection made.</source>
        <translation>Pokud nebude proveden žádný výběr, operace bude zrušena po 60 sekundách.</translation>
    </message>
    <message>
        <source>This message can be disabled via settings.</source>
        <translation>Tuto zprávu lze deaktivovat pomocí nastavení.</translation>
    </message>
</context>
<context>
    <name>SnippingAreaSettings</name>
    <message>
        <source>Freeze Image while snipping</source>
        <translation>Zmrazení obrazu při snímání</translation>
    </message>
    <message>
        <source>When enabled will freeze the background while
selecting a rectangular region. It also changes
the behavior of delayed screenshots, with this
option enabled the delay happens before the
snipping area is shown and with the option disabled
the delay happens after the snipping area is shown.
This feature is always disabled for Wayland and always
enabled for MacOs.</source>
        <translation>Pokud je tato možnost povolena, zamrzne pozadí
při výběru obdélníkové oblasti. Mění také chování
zpožděných snímků obrazovky, s touto možností
povolenou se zpoždění objeví před zobrazením oblasti a
s vypnutou možností se zpoždění provede 
až po zobrazení oblasti. 
Tato funkce nefunguje pro Wayland a je vždy
používána pro MacO.</translation>
    </message>
    <message>
        <source>Show magnifying glass on snipping area</source>
        <translation>Zobrazit lupu v oblasti výstřižku</translation>
    </message>
    <message>
        <source>Show a magnifying glass which zooms into
the background image. This option only works
with &apos;Freeze Image while snipping&apos; enabled.</source>
        <translation>Zobrazit lupu, která přiblíží obrázek na pozadí.
Tato možnost funguje pouze se zapnutou
funkcí &apos;Zmrazení obrazu při snímání&apos;.</translation>
    </message>
    <message>
        <source>Show Snipping Area rulers</source>
        <translation>Zobrazit pravítko oblasti výstřižku</translation>
    </message>
    <message>
        <source>Horizontal and vertical lines going from
desktop edges to cursor on snipping area.</source>
        <translation>Vodorovné a svislé čáry vedoucí z
okraje plochy ke kurzoru snímané oblasti.</translation>
    </message>
    <message>
        <source>Show Snipping Area position and size info</source>
        <translation>Zobrazit informace o poloze a velikosti oblasti snímku</translation>
    </message>
    <message>
        <source>When left mouse button is not pressed the position
is shown, when the mouse button is pressed,
the size of the select area is shown left
and above from the captured area.</source>
        <translation>Pokud není stisknuto levé tlačítko myši,
je zobrazena pozice, při stisknutí tlačítka myši
je zobrazna velikost vybrané oblasti vlevo a nad 
zachycenou oblastí.</translation>
    </message>
    <message>
        <source>Allow resizing rect area selection by default</source>
        <translation>Ve výchozím nastavení povolit změnu velikosti obdélníkové oblasti</translation>
    </message>
    <message>
        <source>When enabled will, after selecting a rect
area, allow resizing the selection. When
done resizing the selection can be confirmed
by pressing return.</source>
        <translation>Je-li povoleno, po výběru obdélníkové
oblasti, je možno změnit velikosti tohot výběru.
Ukončení změny velikosti lze potvrdit
klávesou return.</translation>
    </message>
    <message>
        <source>Show Snipping Area info text</source>
        <translation>Zobrazit text informací o oblasti výstřižku</translation>
    </message>
    <message>
        <source>Snipping Area cursor color</source>
        <translation>Barva kurzoru v oblasti výstřižku</translation>
    </message>
    <message>
        <source>Sets the color of the snipping area cursor.</source>
        <translation>Nastaví barvu kurzoru oblasti výstřižku.</translation>
    </message>
    <message>
        <source>Snipping Area cursor thickness</source>
        <translation>Tloušťka kurzoru v oblasti výstřižku</translation>
    </message>
    <message>
        <source>Sets the thickness of the snipping area cursor.</source>
        <translation>Nastaví tloušťku kurzoru oblasti výstřižku.</translation>
    </message>
    <message>
        <source>Snipping Area</source>
        <translation>Výstřižková oblast</translation>
    </message>
    <message>
        <source>Snipping Area adorner color</source>
        <translation>Barva doplňků Výstřižkové oblasti</translation>
    </message>
    <message>
        <source>Sets the color of all adorner elements
on the snipping area.</source>
        <translation>Nastaví barvu všech doplňkových prvků
v odstřižené oblasti.</translation>
    </message>
    <message>
        <source>Snipping Area Transparency</source>
        <translation>Průhlednost výstřižkové oblasti</translation>
    </message>
    <message>
        <source>Alpha for not selected region on snipping area.
Smaller number is more transparent.</source>
        <translation>Průhlednost pro nevybranou oblast v oblasti výstřižku.
Menší číslo je průhlednější.</translation>
    </message>
</context>
<context>
    <name>StickerSettings</name>
    <message>
        <source>Up</source>
        <translation>Nahoru</translation>
    </message>
    <message>
        <source>Down</source>
        <translation>Dolů</translation>
    </message>
    <message>
        <source>Use Default Stickers</source>
        <translation>Použití výchozích nálepek</translation>
    </message>
    <message>
        <source>Sticker Settings</source>
        <translation>Nastavení nálepky</translation>
    </message>
    <message>
        <source>Vector Image Files (*.svg)</source>
        <translation>Soubory vektorových obrázků (* .svg)</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Přidat</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Odstranit</translation>
    </message>
    <message>
        <source>Add Stickers</source>
        <translation>Přidat samolepky</translation>
    </message>
</context>
<context>
    <name>TrayIcon</name>
    <message>
        <source>Show Editor</source>
        <translation>Zobrazit editor</translation>
    </message>
</context>
<context>
    <name>TrayIconSettings</name>
    <message>
        <source>Use Tray Icon</source>
        <translation>Použít ikonu v oznamovací oblasti</translation>
    </message>
    <message>
        <source>When enabled will add a Tray Icon to the TaskBar if the OS Window Manager supports it.
Change requires restart.</source>
        <translation>Pokud je tato možnost povolena, přidá se ikona do oznamovací oblasti,
pokud ji správce oken sytému podporuje. Změna vyžaduje restart.</translation>
    </message>
    <message>
        <source>Minimize to Tray</source>
        <translation>Minimalizovat do oznamovací oblasti</translation>
    </message>
    <message>
        <source>Start Minimized to Tray</source>
        <translation>Spustit minimalizované do oznamovací oblasti</translation>
    </message>
    <message>
        <source>Close to Tray</source>
        <translation>Zavřít do oznamovací oblasti</translation>
    </message>
    <message>
        <source>Show Editor</source>
        <translation>Zobrazit editor</translation>
    </message>
    <message>
        <source>Capture</source>
        <translation>Zachytit</translation>
    </message>
    <message>
        <source>Default Tray Icon action</source>
        <translation>Výchozí akce pro ikonu v oznamovací oblasti</translation>
    </message>
    <message>
        <source>Default Action that is triggered by left clicking the tray icon.</source>
        <translation>Výchozí akce, která se spustí klepnutím levým tlačítkem myši na ikonu v oznamovací oblasti.</translation>
    </message>
    <message>
        <source>Tray Icon Settings</source>
        <translation>Nastavení ikony v oznamovací oblasti</translation>
    </message>
    <message>
        <source>Use platform specific notification service</source>
        <translation>Používat službu oznámení dané platformy</translation>
    </message>
    <message>
        <source>When enabled will use try to use platform specific notification
service when such exists. Change requires restart to take effect.</source>
        <translation>Pokud je možnost povolená, ksnip se pokusí používat službu oznámení dané platformy, pokud existuje.
Změna vyžaduje restart pro projevení.</translation>
    </message>
    <message>
        <source>Display Tray Icon notifications</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UpdateWatermarkOperation</name>
    <message>
        <source>Select Image</source>
        <translation>Vybrat obrázek</translation>
    </message>
    <message>
        <source>Image Files</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UploadOperation</name>
    <message>
        <source>Upload Script Required</source>
        <translation>Je vyžadován skript pro nahrávání</translation>
    </message>
    <message>
        <source>Please add an upload script via Options &gt; Settings &gt; Upload Script</source>
        <translation>Přidejte prosím skript pro nahrávání pomocí Možnosti&gt; Nastavení&gt; Nahrát skript</translation>
    </message>
    <message>
        <source>Capture Upload</source>
        <translation>Zachytit nahraní</translation>
    </message>
    <message>
        <source>You are about to upload the image to an external destination, do you want to proceed?</source>
        <translation>Chystáte se nahrát obrázek do externího umístění, chcete pokračovat?</translation>
    </message>
</context>
<context>
    <name>UploaderSettings</name>
    <message>
        <source>Ask for confirmation before uploading</source>
        <translation>Před odesláním požádat o potvrzení</translation>
    </message>
    <message>
        <source>Uploader Type:</source>
        <translation>Typ uploaderu:</translation>
    </message>
    <message>
        <source>Imgur</source>
        <translation>Imgur</translation>
    </message>
    <message>
        <source>Script</source>
        <translation>Skript</translation>
    </message>
    <message>
        <source>Uploader</source>
        <translation>Nahrání</translation>
    </message>
    <message>
        <source>FTP</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>VersionTab</name>
    <message>
        <source>Version</source>
        <translation>Verze</translation>
    </message>
    <message>
        <source>Build</source>
        <translation>Sestavení</translation>
    </message>
    <message>
        <source>Using:</source>
        <translation>Používá:</translation>
    </message>
</context>
<context>
    <name>WatermarkSettings</name>
    <message>
        <source>Watermark Image</source>
        <translation>Obrázek vodoznaku</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Aktualizovat</translation>
    </message>
    <message>
        <source>Rotate Watermark</source>
        <translation>Otočit vodoznak</translation>
    </message>
    <message>
        <source>When enabled, Watermark will be added with a rotation of 45°</source>
        <translation>Pokud je povoleno, bude vodoznak přidán s rotací 45 °</translation>
    </message>
    <message>
        <source>Watermark Settings</source>
        <translation>Nastavení vodoznaku</translation>
    </message>
</context>
</TS>
